Coverage for tictactoe/contest/admin: 82%

# Coverage for tictactoe/contest/admin : 82%

## 17 statements 14 run 3 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 | from django.contrib import admin from .models import Entry, LatestEntry, Fight class LatestEntryAdmin(admin.ModelAdmin): list_display = ('user', 'entry') class EntryAdmin(admin.ModelAdmin): actions = ['force_entry_qualification'] list_display = ('user', 'codesize', 'uploaded') def force_entry_qualification(self, request, queryset): for e in queryset: e.qualify() self.message_user(request, "qualification rescheduled for %s." % e) class FightAdmin(admin.ModelAdmin): list_display = ('x', 'o', 'result', 'error') list_filter = ('x__user', 'o__user') admin.site.register(Entry, EntryAdmin) admin.site.register(LatestEntry, LatestEntryAdmin) admin.site.register(Fight, FightAdmin)